==> nextcloud-26.0.9.tgz: nextcloud/apps/federatedfilesharing/l10n/lt_LT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar norite pridėti nuotolinį viešinį {name} iš {owner}@{remote}?",
    "Remote share" : "Nuotolinis viešinys",
    "Remote share password" : "Nuotolinio viešinio slaptažodis",
    "Cancel" : "Atsisakyti",
    "Add remote share" : "Pridėti nuotolinį viešinį",
    "Invalid Federated Cloud ID" : "Neteisingas federacinės debesijos ID",
    "Server to server sharing is not enabled on this server" : "Dalinimasis tarp serverių yra neleidžiamas šiame serveryje",
    "Couldn't establish a federated share." : "Nepavyko užmegzti federacinio viešinio.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepavyko užmegzti federacinio viešinio, galbūt, neteisingas slaptažodis.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federacinio viešinio užklausa išsiųsta, jūs gausite pakvietimą. Tikrinkite savo pranešimus.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepavyko užmegzti federacinio viešinio, atrodo, kad serveris su kuriuo ketinama jungtis į federaciją yra per senas (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Iš šio serverio neleidžiama siųsti federacinių grupės viešinių.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Nepavyko bendrinti %1$s, nes šis elementas jau yra bendrinamas su naudotoju %2$s",
    "Not allowed to create a federated share with the same user" : "Negalima sukurti federacinį viešinį su tuo pačiu naudotoju",
    "File is already shared with %s" : "Failas jau yra bendrinamas su %s",
    "Could not find share" : "Nepavyko rasti bendrinamų duomenų",
    "Federated sharing" : "Federacinis bendrinimas",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Jūs gavote {share} kaip nuotolinį viešinį iš {user} ({behalf} vardu)",
    "You received {share} as a remote share from {user}" : "Jūs gavote {share} kaip nuotolinį viešinį iš {user}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Federated Cloud Sharing" : "Bendrinimas federacinėje debesijoje",
    "Sharing" : "Duomenų bendrinimas",
    "Federated file sharing" : "Federacinis failų bendrinimas",
    "Allow users on this server to receive shares from other servers" : "Leisti naudotojams šiame serveryje gauti viešinius iš kitų serverių",
    "Allow users on this server to send shares to groups on other servers" : "Leisti naudotojams šiame serveryje siųsti viešinius į grupes kituose serveriuose",
    "Allow users on this server to receive group shares from other servers" : "Leisti naudotojams šiame serveryje gauti grupių viešinius iš kitų serverių",
    "Search global and public address book for users" : "Ieškoti naudotojų visuotinėje ir viešoje adresų knygoje",
    "Allow users to publish their data to a global and public address book" : "Leisti naudotojams paskelbti savo duomenis visuotinėje ir viešoje adresų knygoje",
    "Federated Cloud" : "Federacinė debesija",
    "Your Federated Cloud ID:" : "Jūsų federacinės debesijos ID:",
    "Share it so your friends can share files with you:" : "Pasidalinkite juo, kad jūsų draugai galėtų bendrinti failus kartu su jumis:",
    "Facebook" : "„Facebook“",
    "Twitter" : "Twitter",
    "HTML Code:" : "HTML kodas:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Bendrinti su manimi per mano #Nextcloud federacinės debesijos ID",
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Clipboard is not available" : "Iškarpinė neprieinama",
    "Copied!" : "Nukopijuota!"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/federatedfilesharing/l10n/lt_LT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Neteisingas federacinės debesijos ID",
    "Server to server sharing is not enabled on this server" : "Dalinimasis tarp serverių yra neleidžiamas šiame serveryje",
    "Couldn't establish a federated share." : "Nepavyko užmegzti federacinio viešinio.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepavyko užmegzti federacinio viešinio, galbūt, neteisingas slaptažodis.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federacinio viešinio užklausa išsiųsta, jūs gausite pakvietimą. Tikrinkite savo pranešimus.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepavyko užmegzti federacinio viešinio, atrodo, kad serveris su kuriuo ketinama jungtis į federaciją yra per senas (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Iš šio serverio neleidžiama siųsti federacinių grupės viešinių.",
    "File is already shared with %s" : "Failas jau yra bendrinamas su %s",
    "Could not find share" : "Nepavyko rasti bendrinamų duomenų",
    "Federated sharing" : "Federacinis bendrinimas",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Jūs gavote {share} kaip nuotolinį viešinį iš {user} ({behalf} vardu)",
    "You received {share} as a remote share from {user}" : "Jūs gavote {share} kaip nuotolinį viešinį iš {user}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Federated Cloud Sharing" : "Bendrinimas federacinėje debesijoje",
    "Sharing" : "Duomenų bendrinimas",
    "Federated file sharing" : "Federacinis failų bendrinimas",
    "Federated Cloud" : "Federacinė debesija",
    "Your Federated Cloud ID:" : "Jūsų federacinės debesijos ID:",
    "Share it so your friends can share files with you:" : "Pasidalinkite juo, kad jūsų draugai galėtų bendrinti failus kartu su jumis:",
    "Facebook" : "„Facebook“",
    "Twitter" : "Twitter",
    "HTML Code:" : "HTML kodas:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Bendrinti su manimi per mano #Nextcloud federacinės debesijos ID",
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Clipboard is not available" : "Iškarpinė neprieinama",
    "Copied!" : "Nukopijuota!",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar norite pridėti nuotolinį viešinį {name} iš {owner}@{remote}?",
    "Remote share" : "Nuotolinis viešinys",
    "Remote share password" : "Nuotolinio viešinio slaptažodis",
    "Cancel" : "Atsisakyti",
    "Add remote share" : "Pridėti nuotolinį viešinį",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Nepavyko bendrinti %1$s, nes šis elementas jau yra bendrinamas su naudotoju %2$s",
    "Not allowed to create a federated share with the same user" : "Negalima sukurti federacinį viešinį su tuo pačiu naudotoju",
    "Allow users on this server to receive shares from other servers" : "Leisti naudotojams šiame serveryje gauti viešinius iš kitų serverių",
    "Allow users on this server to send shares to groups on other servers" : "Leisti naudotojams šiame serveryje siųsti viešinius į grupes kituose serveriuose",
    "Allow users on this server to receive group shares from other servers" : "Leisti naudotojams šiame serveryje gauti grupių viešinius iš kitų serverių",
    "Search global and public address book for users" : "Ieškoti naudotojų visuotinėje ir viešoje adresų knygoje",
    "Allow users to publish their data to a global and public address book" : "Leisti naudotojams paskelbti savo duomenis visuotinėje ir viešoje adresų knygoje"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
